@@ -13,12 +13,13 @@ package Device::I2C::ADV7611;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # Dependencies
 use 5.010;
 use Device::I2C;
 use Fcntl;
+use Carp;
 
 use constant CTRL_IO   => 0x4c;
 use constant CTRL_HDMI => 0x34;
@@ -28,6 +29,9 @@ use constant CTRL_INFO => 0x3E;
 use constant CTRL_KSV  => 0x32;
 use constant CTRL_EDID => 0x36;
 use constant CTRL_CP   => 0x22;
+use Exporter qw(import);
+our @EXPORT_OK = qw(CTRL_IO CTRL_HDMI CTRL_DPLL CTRL_CEC
+  CTRL_INFO CTRL_KSV CTRL_EDID CTRL_CP );
 
 sub new {
     my $class = shift;
@@ -60,13 +64,13 @@ sub checkCable {
 
 sub writeRegister {
     my ( $io, $addr, $register, $value ) = @_;
-    $io->select_device($addr);
+    $io->selectDevice($addr);
     $io->writeByteData( $register, $value );
 }
 
 sub readRegister {
     my ( $io, $addr, $register ) = @_;
-    $io->select_device($addr);
+    $io->selectDevice($addr);
     return $io->readByteData($register);
 }
 
@@ -167,8 +171,8 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.02"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.02" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.02"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.02" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.03"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.03" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.03"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.03" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -176,7 +180,7 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
